Task: QA CNN
=============
Description: Cloze dataset based on a missing (anonymized) entity phrase from a CNN article, Hermann et al. '15. 

Link: https://arxiv.org/abs/1506.03340

Tags: #QACNN, #All, #Cloze

